.. ==================================================
.. FOR YOUR INFORMATION
.. --------------------------------------------------
.. -*- coding: utf-8 -*- with BOM.

.. include:: Includes.txt

.. _start:

=============================================================
privacyidea
=============================================================

.. only:: html

	:Classification:
		privacyidea

	:Version:
		|release|

	:Language:
		en

	:Description:
		Two factor authentication for TYPO3 frontend and backend authenticating
		against your own privacyIDEA server.
		privacyIDEA supports many different type of authentication devices
		like OTP token, display cards, Yubikey, SMS, Email...

	:Keywords:
		OTP, One Time Password, Two Factor Authentication, Authentication,
		Secure Login, Security

	:Copyright:
		2015

	:Author:
		Cornelius Kölbel

	:Email:
		cornelius.koelbel@netknights.it

	:License:
		This document is published under the Open Content License
		available from http://www.opencontent.org/opl.shtml

	:Rendered:
		|today|

	The content of this document is related to TYPO3,
	a GNU/GPL CMS/Framework available from `www.typo3.org <http://www.typo3.org/>`_.

	**Table of Contents**

.. toctree::
	:maxdepth: 5
	:titlesonly:
	:glob:

	Introduction/Index
	Configuration/Index
	KnownProblems/Index
	ToDoList/Index
	ChangeLog/Index
